==> gnumach-1.2.tar.gz: gnumach-1.2/kern/assert.h <==
/* 
 * Mach Operating System
 * Copyright (c) 1991,1990,1989,1988,1987 Carnegie Mellon University
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify and distribute this software and its
 * documentation is hereby granted, provided that both the copyright
 * notice and this permission notice appear in all copies of the
 * software, derivative works or modified versions, and any portions
 * thereof, and that both notices appear in supporting documentation.
 * 
 * CARNEGIE MELLON ALLOWS FREE USE OF THIS SOFTWARE IN ITS "AS IS"
 * CONDITION.  CARNEGIE MELLON DISCLAIMS ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Carnegie Mellon requests users of this software to return to
 * 
 *  Software Distribution Coordinator  or  Software.Distribution@CS.CMU.EDU
 *  School of Computer Science
 *  Carnegie Mellon University
 *  Pittsburgh PA 15213-3890
 * 
 * any improvements or extensions that they make and grant Carnegie Mellon
 * the rights to redistribute these changes.
 */

#ifndef	_KERN_ASSERT_H_
#define	_KERN_ASSERT_H_

/*	assert.h	4.2	85/01/21	*/

#include <kern/macro_help.h>

#ifdef DEBUG
#define MACH_ASSERT 1
#endif

#if	MACH_ASSERT
extern void Assert(char *exp, char *filename, int line);

#define assert(ex)							\
MACRO_BEGIN								\
	if (!(ex))							\
		Assert(#ex, __FILE__, __LINE__);			\
MACRO_END

#ifdef	lint
#define	assert_static(x)
#else	lint
#define	assert_static(x)	assert(x)
#endif	lint

#else	MACH_ASSERT
#define assert(ex)
#define assert_static(ex)
#endif	MACH_ASSERT

#endif	_KERN_ASSERT_H_

==> gnumach-1.3.tar.gz: gnumach-1.3/kern/assert.h <==
/*
 * Mach Operating System
 * Copyright (c) 1991,1990,1989,1988,1987 Carnegie Mellon University
 * All Rights Reserved.
 *
 * Permission to use, copy, modify and distribute this software and its
 * documentation is hereby granted, provided that both the copyright
 * notice and this permission notice appear in all copies of the
 * software, derivative works or modified versions, and any portions
 * thereof, and that both notices appear in supporting documentation.
 *
 * CARNEGIE MELLON ALLOWS FREE USE OF THIS SOFTWARE IN ITS "AS IS"
 * CONDITION.  CARNEGIE MELLON DISCLAIMS ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 *
 * Carnegie Mellon requests users of this software to return to
 *
 *  Software Distribution Coordinator  or  Software.Distribution@CS.CMU.EDU
 *  School of Computer Science
 *  Carnegie Mellon University
 *  Pittsburgh PA 15213-3890
 *
 * any improvements or extensions that they make and grant Carnegie Mellon
 * the rights to redistribute these changes.
 */

#ifndef	_KERN_ASSERT_H_
#define	_KERN_ASSERT_H_

/*	assert.h	4.2	85/01/21	*/

#include <kern/macro_help.h>

#ifdef DEBUG
#define MACH_ASSERT 1
#endif

#if	MACH_ASSERT
extern void Assert(char *exp, char *filename, int line);

#define assert(ex)							\
MACRO_BEGIN								\
	if (!(ex))							\
		Assert(#ex, __FILE__, __LINE__);			\
MACRO_END

#ifdef	lint
#define	assert_static(x)
#else	/* lint */
#define	assert_static(x)	assert(x)
#endif	/* lint */

#else	/* MACH_ASSERT */
#define assert(ex)
#define assert_static(ex)
#endif	/* MACH_ASSERT */

#endif	/* _KERN_ASSERT_H_ */
